@@ -1,27 +1,27 @@
 """Module providing WalkletsSkipGram model implementation."""
-from typing import Optional
-from embiggen.embedders.ensmallen_embedders.node2vec import Node2VecEnsmallen
+from typing import Optional, Dict, Any
+from embiggen.embedders.ensmallen_embedders.walklets import WalkletsEnsmallen
 
 
-class WalkletsSkipGramEnsmallen(Node2VecEnsmallen):
+class WalkletsSkipGramEnsmallen(WalkletsEnsmallen):
     """Class providing WalkletsSkipGram implemeted in Rust from Ensmallen."""
 
     def __init__(
         self,
         embedding_size: int = 100,
-        epochs: int = 10,
+        epochs: int = 30,
         clipping_value: float = 6.0,
         number_of_negative_samples: int = 10,
         walk_length: int = 128,
         iterations: int = 10,
-        window_size: int = 10,
+        window_size: int = 4,
         return_weight: float = 1.0,
         explore_weight: float = 1.0,
-        change_node_type_weight: float = 1.0,
-        change_edge_type_weight: float = 1.0,
         max_neighbours: Optional[int] = 100,
         learning_rate: float = 0.01,
         learning_rate_decay: float = 0.9,
+        central_nodes_embedding_path: Optional[str] = None,
+        contextual_nodes_embedding_path: Optional[str] = None,
         normalize_by_degree: bool = False,
         stochastic_downsample_by_degree: Optional[bool] = False,
         normalize_learning_rate_by_degree: Optional[bool] = False,
@@ -35,7 +35,7 @@ class WalkletsSkipGramEnsmallen(Node2VecEnsmallen):
         --------------------------
         embedding_size: int = 100
             Dimension of the embedding.
-        epochs: int = 10
+        epochs: int = 30
             Number of epochs to train the model for.
         clipping_value: float = 6.0
             Value at which we clip the dot product, mostly for numerical stability issues.
@@ -47,7 +47,7 @@ class WalkletsSkipGramEnsmallen(Node2VecEnsmallen):
             Maximal length of the walks.
         iterations: int = 10
             Number of iterations of the single walks.
-        window_size: int = 10
+        window_size: int = 4
             Window size for the local context.
             On the borders the window size is trimmed.
         return_weight: float = 1.0
@@ -64,14 +64,6 @@ class WalkletsSkipGramEnsmallen(Node2VecEnsmallen):
             Having this very high makes search more outward.
             Having this very low makes search very local.
             Equal to the inverse of q in the Node2Vec paper.
-        change_node_type_weight: float = 1.0
-            Weight on the probability of visiting a neighbor node of a
-            different type than the previous node. This only applies to
-            colored graphs, otherwise it has no impact.
-        change_edge_type_weight: float = 1.0
-            Weight on the probability of visiting a neighbor edge of a
-            different type than the previous edge. This only applies to
-            multigraphs, otherwise it has no impact.
         max_neighbours: Optional[int] = 100
             Number of maximum neighbours to consider when using approximated walks.
             By default, None, we execute exact random walks.
@@ -80,6 +72,18 @@ class WalkletsSkipGramEnsmallen(Node2VecEnsmallen):
             The learning rate to use to train the Node2Vec model. By default 0.01.
         learning_rate_decay: float = 0.9
             Factor to reduce the learning rate for at each epoch. By default 0.9.
+        central_nodes_embedding_path: Optional[str] = None
+            Path where to mmap and store the central nodes embedding.
+            If provided, we expect the path to contain the substring `{window_size}` which
+            will be replaced with the i-th window size embedding that is being computed.
+            This is necessary to embed large graphs whose embedding will not
+            fit into the available main memory.
+        contextual_nodes_embedding_path: Optional[str] = None
+            Path where to mmap and store the central nodes embedding.
+            If provided, we expect the path to contain the substring `{window_size}` which
+            will be replaced with the i-th window size embedding that is being computed.
+            This is necessary to embed large graphs whose embedding will not
+            fit into the available main memory.
         normalize_by_degree: bool = False
             Whether to normalize the random walk by the node degree
             of the destination node degrees.
@@ -96,8 +100,7 @@ class WalkletsSkipGramEnsmallen(Node2VecEnsmallen):
             store the computed embedding.
         """
         super().__init__(
-            model_name="WalkletsSkipGram",
-            embedding_size=embedding_size // window_size,
+            embedding_size=embedding_size,
             epochs=epochs,
             clipping_value=clipping_value,
             number_of_negative_samples=number_of_negative_samples,
@@ -106,11 +109,11 @@ class WalkletsSkipGramEnsmallen(Node2VecEnsmallen):
             window_size=window_size,
             return_weight=return_weight,
             explore_weight=explore_weight,
-            change_edge_type_weight=change_edge_type_weight,
-            change_node_type_weight=change_node_type_weight,
             max_neighbours=max_neighbours,
             learning_rate=learning_rate,
             learning_rate_decay=learning_rate_decay,
+            central_nodes_embedding_path=central_nodes_embedding_path,
+            contextual_nodes_embedding_path=contextual_nodes_embedding_path,
             normalize_by_degree=normalize_by_degree,
             stochastic_downsample_by_degree=stochastic_downsample_by_degree,
             normalize_learning_rate_by_degree=normalize_learning_rate_by_degree,
@@ -118,16 +121,21 @@ class WalkletsSkipGramEnsmallen(Node2VecEnsmallen):
             random_state=random_state,
             enable_cache=enable_cache
         )
-    
+
+    def parameters(self) -> Dict[str, Any]:
+        """Returns parameters for smoke test."""
+        removed = [
+            "alpha",
+        ]
+        return dict(
+            **{
+                key: value
+                for key, value in super().parameters().items()
+                if key not in removed
+            }
+        )
+
     @classmethod
     def model_name(cls) -> str:
         """Returns name of the model."""
         return "Walklets SkipGram"
-
-    @classmethod
-    def requires_node_types(cls) -> bool:
-        return False
-
-    @classmethod
-    def requires_edge_types(cls) -> bool:
-        return False
\ No newline at end of file
