@@ -33,6 +33,7 @@ class AbstractEdgeGCN(AbstractGCN):
         number_of_units_per_ffnn_head_layer: Union[int, List[int]] = 128,
         dropout_rate: float = 0.3,
         apply_norm: bool = False,
+        combiner: str ="sum",
         edge_embedding_method: str = "Concatenate",
         optimizer: Union[str, Optimizer] = "adam",
         early_stopping_min_delta: float = 0.0001,
@@ -86,6 +87,13 @@ class AbstractEdgeGCN(AbstractGCN):
         apply_norm: bool = False
             Whether to normalize the output of the convolution operations,
             after applying the level activations.
+        combiner: str = "mean"
+            A string specifying the reduction op.
+            Currently "mean", "sqrtn" and "sum" are supported. 
+            "sum" computes the weighted sum of the embedding results for each row.
+            "mean" is the weighted sum divided by the total weight.
+            "sqrtn" is the weighted sum divided by the square root of the sum of the squares of the weights.
+            Defaults to mean.
         edge_embedding_method: str = "Concatenate"
             The edge embedding method to use to put togheter the
             source and destination node features, which includes:
@@ -195,6 +203,7 @@ class AbstractEdgeGCN(AbstractGCN):
             number_of_units_per_graph_convolution_layers=number_of_units_per_graph_convolution_layers,
             dropout_rate=dropout_rate,
             apply_norm=apply_norm,
+            combiner=combiner,
             optimizer=optimizer,
             early_stopping_min_delta=early_stopping_min_delta,
             early_stopping_patience=early_stopping_patience,
@@ -353,28 +362,29 @@ class AbstractEdgeGCN(AbstractGCN):
             edge_metrics = None
 
         edge_feature_inputs = []
-        if edge_features is not None:
-            edge_feature_names = self._edge_feature_names
-            if edge_feature_names is None:
-                edge_feature_names = [
-                    f"{number_to_ordinal(i+1)}EdgeFeature"
-                    for i in range(len(edge_features))
-                ]
-            if len(edge_feature_names) != len(edge_features):
-                raise ValueError(
-                    f"You have provided {len(edge_feature_names)} "
-                    f"edge feature names but you have provided {len(edge_features)} "
-                    "edge features to the model."
-                )
-            for edge_feature, feature_name in zip(edge_features, edge_feature_names):
-                feature_names.append(feature_name)
-                edge_feature_input = Input(
-                    shape=edge_feature.shape[1:],
-                    batch_size=nodes_number,
-                    name=feature_name,
-                )
-                edge_feature_inputs.append(edge_feature_input)
-                source_and_destination_features.append(edge_feature_input)
+        if edge_features is None:
+            edge_features = []
+        edge_feature_names = self._edge_feature_names
+        if edge_feature_names is None:
+            edge_feature_names = [
+                f"{number_to_ordinal(i+1)}EdgeFeature"
+                for i in range(len(edge_features))
+            ]
+        if len(edge_feature_names) != len(edge_features):
+            raise ValueError(
+                f"You have provided {len(edge_feature_names)} "
+                f"edge feature names but you have provided {len(edge_features)} "
+                "edge features to the model."
+            )
+        for edge_feature, feature_name in zip(edge_features, edge_feature_names):
+            feature_names.append(feature_name)
+            edge_feature_input = Input(
+                shape=edge_feature.shape[1:],
+                batch_size=nodes_number,
+                name=feature_name,
+            )
+            edge_feature_inputs.append(edge_feature_input)
+            source_and_destination_features.append(edge_feature_input)
 
         ffnn_outputs = []
 
@@ -459,19 +469,21 @@ class AbstractEdgeGCN(AbstractGCN):
             name="Output"
         )(hidden)
 
+        inputs=[
+            input_layer
+            for input_layer in (
+                source_nodes,
+                destination_nodes,
+                edge_metrics,
+                *edge_feature_inputs,
+                *graph_convolution_model.inputs,
+            )
+            if input_layer is not None
+        ]
+
         # Building the the model.
         model = Model(
-            inputs=[
-                input_layer
-                for input_layer in (
-                    source_nodes,
-                    destination_nodes,
-                    edge_metrics,
-                    *edge_feature_inputs,
-                    *graph_convolution_model.inputs,
-                )
-                if input_layer is not None
-            ],
+            inputs=inputs,
             outputs=output,
             name=self.model_name().replace(" ", "_")
         )
