@@ -159,7 +159,7 @@ class AbstractClassifierModel(AbstractModel):
     @classmethod
     def load(cls, path: str) -> "Self":
         """Load a saved version of the model from the provided path.
-        
+
         Parameters
         -------------------
         path: str
@@ -173,7 +173,7 @@ class AbstractClassifierModel(AbstractModel):
 
     def dump(self, path: str):
         """Dump the current model at the provided path.
-        
+
         Parameters
         -------------------
         path: str
@@ -194,7 +194,7 @@ class AbstractClassifierModel(AbstractModel):
         allow_automatic_feature: bool = True,
         skip_evaluation_biased_feature: bool = False,
         smoke_test: bool = False,
-        precompute_constant_automatic_stocastic_features: bool = False
+        precompute_constant_stocastic_features: bool = False
     ) -> List[np.ndarray]:
         """Normalizes the provided node features and validates them.
 
@@ -219,7 +219,7 @@ class AbstractClassifierModel(AbstractModel):
             Whether this run should be considered a smoke test
             and therefore use the smoke test configurations for
             the provided model names and feature names.
-        precompute_constant_automatic_stocastic_features: bool = False
+        precompute_constant_stocastic_features: bool = False
             Whether to precompute once the constant automatic stocastic
             features before starting the embedding loop. This means that,
             when left set to false, while the features will be computed
@@ -259,7 +259,7 @@ class AbstractClassifierModel(AbstractModel):
                     cls.task_involves_edge_weights() and node_feature.can_use_edge_weights() and node_feature.is_using_edge_weights() or
                     cls.task_involves_topology() and node_feature.is_topological()
                 ) or
-                not precompute_constant_automatic_stocastic_features and node_feature.is_stocastic()
+                not precompute_constant_stocastic_features and node_feature.is_stocastic()
             ):
                 yield node_feature
                 return None
@@ -327,7 +327,7 @@ class AbstractClassifierModel(AbstractModel):
         allow_automatic_feature: bool = True,
         skip_evaluation_biased_feature: bool = False,
         smoke_test: bool = False,
-        precompute_constant_automatic_stocastic_features: bool = False
+        precompute_constant_stocastic_features: bool = False
     ) -> List[np.ndarray]:
         """Normalizes the provided node features and validates them.
 
@@ -352,7 +352,7 @@ class AbstractClassifierModel(AbstractModel):
             Whether this run should be considered a smoke test
             and therefore use the smoke test configurations for
             the provided model names and feature names.
-        precompute_constant_automatic_stocastic_features: bool = False
+        precompute_constant_stocastic_features: bool = False
             Whether to precompute once the constant automatic stocastic
             features before starting the embedding loop. This means that,
             when left set to false, while the features will be computed
@@ -378,7 +378,7 @@ class AbstractClassifierModel(AbstractModel):
                 allow_automatic_feature=allow_automatic_feature,
                 skip_evaluation_biased_feature=skip_evaluation_biased_feature,
                 smoke_test=smoke_test,
-                precompute_constant_automatic_stocastic_features=precompute_constant_automatic_stocastic_features
+                precompute_constant_stocastic_features=precompute_constant_stocastic_features
             )
         ]
 
@@ -391,7 +391,7 @@ class AbstractClassifierModel(AbstractModel):
         allow_automatic_feature: bool = True,
         skip_evaluation_biased_feature: bool = False,
         smoke_test: bool = False,
-        precompute_constant_automatic_stocastic_features: bool = False
+        precompute_constant_stocastic_features: bool = False
     ) -> List[np.ndarray]:
         """Normalizes the provided node type features and validates them.
 
@@ -416,7 +416,7 @@ class AbstractClassifierModel(AbstractModel):
             Whether this run should be considered a smoke test
             and therefore use the smoke test configurations for
             the provided model names and feature names.
-        precompute_constant_automatic_stocastic_features: bool = False
+        precompute_constant_stocastic_features: bool = False
             Whether to precompute once the constant automatic stocastic
             features before starting the embedding loop. This means that,
             when left set to false, while the features will be computed
@@ -456,11 +456,11 @@ class AbstractClassifierModel(AbstractModel):
                     cls.task_involves_edge_weights() and node_type_feature.is_using_edge_weights() or
                     cls.task_involves_topology() and node_type_feature.is_topological()
                 ) or
-                not precompute_constant_automatic_stocastic_features and node_type_feature.is_stocastic()
+                not precompute_constant_stocastic_features and node_type_feature.is_stocastic()
             ):
                 yield node_type_feature
                 return None
-            
+
             if node_type_feature.is_stocastic():
                 node_type_feature.set_random_state(random_state)
 
@@ -524,7 +524,7 @@ class AbstractClassifierModel(AbstractModel):
         allow_automatic_feature: bool = True,
         skip_evaluation_biased_feature: bool = False,
         smoke_test: bool = False,
-        precompute_constant_automatic_stocastic_features: bool = False
+        precompute_constant_stocastic_features: bool = False
     ) -> List[np.ndarray]:
         """Normalizes the provided node type features and validates them.
 
@@ -549,7 +549,7 @@ class AbstractClassifierModel(AbstractModel):
             Whether this run should be considered a smoke test
             and therefore use the smoke test configurations for
             the provided model names and feature names.
-        precompute_constant_automatic_stocastic_features: bool = False
+        precompute_constant_stocastic_features: bool = False
             Whether to precompute once the constant automatic stocastic
             features before starting the embedding loop. This means that,
             when left set to false, while the features will be computed
@@ -575,7 +575,7 @@ class AbstractClassifierModel(AbstractModel):
                 allow_automatic_feature=allow_automatic_feature,
                 skip_evaluation_biased_feature=skip_evaluation_biased_feature,
                 smoke_test=smoke_test,
-                precompute_constant_automatic_stocastic_features=precompute_constant_automatic_stocastic_features
+                precompute_constant_stocastic_features=precompute_constant_stocastic_features
             )
         ]
 
@@ -588,7 +588,7 @@ class AbstractClassifierModel(AbstractModel):
         allow_automatic_feature: bool = True,
         skip_evaluation_biased_feature: bool = False,
         smoke_test: bool = False,
-        precompute_constant_automatic_stocastic_features: bool = False
+        precompute_constant_stocastic_features: bool = False
     ) -> List[np.ndarray]:
         """Normalizes the provided edge features and validates them.
 
@@ -613,7 +613,7 @@ class AbstractClassifierModel(AbstractModel):
             Whether this run should be considered a smoke test
             and therefore use the smoke test configurations for
             the provided model names and feature names.
-        precompute_constant_automatic_stocastic_features: bool = False
+        precompute_constant_stocastic_features: bool = False
             Whether to precompute once the constant automatic stocastic
             features before starting the embedding loop. This means that,
             when left set to false, while the features will be computed
@@ -653,7 +653,7 @@ class AbstractClassifierModel(AbstractModel):
                     cls.task_involves_edge_weights() and edge_feature.is_using_edge_weights() or
                     cls.task_involves_topology() and edge_feature.is_topological()
                 ) or
-                not precompute_constant_automatic_stocastic_features and edge_feature.is_stocastic()
+                not precompute_constant_stocastic_features and edge_feature.is_stocastic()
             ):
                 yield edge_feature
                 return None
@@ -721,7 +721,7 @@ class AbstractClassifierModel(AbstractModel):
         allow_automatic_feature: bool = True,
         skip_evaluation_biased_feature: bool = False,
         smoke_test: bool = False,
-        precompute_constant_automatic_stocastic_features: bool = False
+        precompute_constant_stocastic_features: bool = False
     ) -> List[np.ndarray]:
         """Normalizes the provided edge features and validates them.
 
@@ -746,7 +746,7 @@ class AbstractClassifierModel(AbstractModel):
             Whether this run should be considered a smoke test
             and therefore use the smoke test configurations for
             the provided model names and feature names.
-        precompute_constant_automatic_stocastic_features: bool = False
+        precompute_constant_stocastic_features: bool = False
             Whether to precompute once the constant automatic stocastic
             features before starting the embedding loop. This means that,
             when left set to false, while the features will be computed
@@ -772,7 +772,7 @@ class AbstractClassifierModel(AbstractModel):
                 allow_automatic_feature=allow_automatic_feature,
                 skip_evaluation_biased_feature=skip_evaluation_biased_feature,
                 smoke_test=smoke_test,
-                precompute_constant_automatic_stocastic_features=precompute_constant_automatic_stocastic_features
+                precompute_constant_stocastic_features=precompute_constant_stocastic_features
             )
         ]
 
@@ -896,7 +896,7 @@ class AbstractClassifierModel(AbstractModel):
 
         if support is None:
             support = graph
-        
+
         try:
             predictions = self._predict(
                 graph=graph,
@@ -926,7 +926,7 @@ class AbstractClassifierModel(AbstractModel):
                 f"implemented using the {self.library_name()} for the {self.task_name()} task. "
                 f"Specifically, the class of the model is {self.__class__.__name__}."
             ) from e
-            
+
         return predictions
 
     def predict_proba(
@@ -1011,7 +1011,7 @@ class AbstractClassifierModel(AbstractModel):
                 "returned a vector of prediction probabilities with "
                 f"shape {predictions.shape}."
             )
-            
+
         return predictions
 
     def evaluate_predictions(
@@ -1259,11 +1259,12 @@ class AbstractClassifierModel(AbstractModel):
         cache_path="{cache_dir}/{self.task_name()}/{graph.get_name()}/holdout_{holdout_number}/{self.model_name()}/{self.library_name()}/{_hash}.csv.gz",
         cache_dir="experiments",
         enable_cache_arg_name="enable_cache",
-        args_to_ignore=["verbose", "smoke_test", "train_of_interest", "test_of_interest", "train",],
+        args_to_ignore=["verbose", "smoke_test",
+                        "train_of_interest", "test_of_interest", "train", ],
         capture_enable_cache_arg_name=True,
         use_approximated_hash=True
     )
-    def __train_and_evaluate_model(
+    def _train_and_evaluate_model(
         self,
         graph: Graph,
         train_of_interest: Graph,
@@ -1277,8 +1278,8 @@ class AbstractClassifierModel(AbstractModel):
         random_state: int,
         holdout_number: int,
         evaluation_schema: str,
-        automatic_features_names: List[str],
-        automatic_features_parameters: Dict[str, Any],
+        features_names: List[str],
+        features_parameters: Dict[str, Any],
         **validation_kwargs
     ) -> pd.DataFrame:
         """Run inner training and evaluation."""
@@ -1288,7 +1289,7 @@ class AbstractClassifierModel(AbstractModel):
         training_start = time.time()
         self.fit(
             graph=train_of_interest,
-            support= train_of_interest if use_subgraph_as_support else train,
+            support=train_of_interest if use_subgraph_as_support else train,
             node_features=node_features,
             node_type_features=node_type_features,
             edge_features=edge_features
@@ -1311,7 +1312,7 @@ class AbstractClassifierModel(AbstractModel):
                 random_state=random_state * holdout_number,
                 verbose=False,
                 **validation_kwargs
-            ))
+            )).reset_index(drop=True)
         except RuntimeError as e:
             raise e
         except Exception as e:
@@ -1322,7 +1323,7 @@ class AbstractClassifierModel(AbstractModel):
             ) from e
 
         time_required_for_evaluation = time.time() - start_evaluation
-
+    
         model_performance["time_required_for_training"] = time_required_for_training
         model_performance["time_required_for_evaluation"] = time_required_for_evaluation
         model_performance["task_name"] = self.task_name()
@@ -1334,25 +1335,25 @@ class AbstractClassifierModel(AbstractModel):
         model_performance["evaluation_schema"] = evaluation_schema
         model_performance["use_subgraph_as_support"] = use_subgraph_as_support
 
+        model_parameters = pd.DataFrame(dict(), index=model_performance.index)
+        features_parameters = pd.DataFrame(dict(), index=model_performance.index)
+
         for parameter_name, parameter_value in self.parameters().items():
-            if ("Model", parameter_name) in model_performance.columns:
-                raise ValueError(
-                    "There has been a collision between the column names used in "
-                    "the model performance report and the parameter names "
-                    f" of one of the classifiers {self.model_name()}."
-                    f"The parameter that has caused the collision is {parameter}. "
-                    "Please do change the name of the parameter in your model."
-                )
             if isinstance(parameter_value, (list, tuple)):
                 parameter_value = str(parameter_value)
-            model_performance[("Model", parameter_name)] = parameter_value
-        
-        model_performance["automatic_features_names"] = format_list(
-            automatic_features_names
+            model_parameters[parameter_name] = parameter_value
+
+        model_parameters.columns = [
+            ["model_parameters"] * len(model_parameters.columns),
+            model_parameters.columns
+        ]
+
+        model_performance["features_names"] = format_list(
+            features_names
         )
-        
-        for parameter, value in enumerate(automatic_features_parameters.items()):
-            if parameter in model_performance.columns:
+
+        for parameter, value in features_parameters.items():
+            if parameter in features_parameters.columns:
                 raise ValueError(
                     "There has been a collision between the parameters used in "
                     "one of the embedding models and the parameter "
@@ -1360,7 +1361,21 @@ class AbstractClassifierModel(AbstractModel):
                     f"The parameter that has caused the collision is {parameter}. "
                     "Please do change the name of the parameter in your model."
                 )
-            model_performance[parameter] = str(value)
+            features_parameters[parameter] = str(value)
+
+        features_parameters.columns = [
+            ["features_parameters"] * len(features_parameters.columns),
+            features_parameters.columns
+        ]
+
+        model_performance = pd.concat(
+            [
+                model_performance,
+                model_parameters,
+                features_parameters
+            ],
+            axis=1
+        )
 
         return model_performance
 
@@ -1369,7 +1384,14 @@ class AbstractClassifierModel(AbstractModel):
         cache_path="{cache_dir}/{cls.task_name()}/{graph.get_name()}/holdout_{holdout_number}/{_hash}.csv.gz",
         cache_dir="experiments",
         enable_cache_arg_name="enable_cache",
-        args_to_ignore=["verbose", "smoke_test", "number_of_holdouts"],
+        args_to_ignore=[
+            "verbose",
+            "smoke_test",
+            "number_of_holdouts",
+            "time_required_to_compute_constant_node_features",
+            "time_required_to_compute_constant_node_type_features",
+            "time_required_to_compute_constant_edge_features"
+        ],
         capture_enable_cache_arg_name=False,
         use_approximated_hash=True
     )
@@ -1391,8 +1413,8 @@ class AbstractClassifierModel(AbstractModel):
         smoke_test: bool,
         holdouts_kwargs: Dict[str, Any],
         subgraph_of_interest_has_compatible_nodes: Optional[bool],
-        automatic_features_names: List[str],
-        automatic_features_parameters: Dict[str, Any],
+        features_names: List[str],
+        features_parameters: Dict[str, Any],
         verbose: bool,
         **validation_kwargs
     ) -> pd.DataFrame:
@@ -1416,14 +1438,9 @@ class AbstractClassifierModel(AbstractModel):
             vector_cumulative_node_degrees=graph.has_cumulative_node_degrees_tradeoff_enabled(),
             vector_reciprocal_sqrt_degrees=graph.has_reciprocal_sqrt_degrees_tradeoff_enabled()
         )
-        test.enable(
-            vector_sources=graph.has_sources_tradeoff_enabled(),
-            vector_destinations=graph.has_destinations_tradeoff_enabled(),
-            vector_cumulative_node_degrees=graph.has_cumulative_node_degrees_tradeoff_enabled(),
-            vector_reciprocal_sqrt_degrees=graph.has_reciprocal_sqrt_degrees_tradeoff_enabled()
-        )
 
         # We compute the remaining features
+        starting_to_compute_node_features = time.time()
         holdout_node_features = cls.normalize_node_features(
             train,
             random_state=random_state*(holdout_number+1),
@@ -1431,10 +1448,13 @@ class AbstractClassifierModel(AbstractModel):
             allow_automatic_feature=True,
             skip_evaluation_biased_feature=False,
             smoke_test=smoke_test,
-            precompute_constant_automatic_stocastic_features=True
+            precompute_constant_stocastic_features=True
         )
+        time_required_to_compute_node_features = time.time() - \
+            starting_to_compute_node_features
 
         # We compute the remaining features
+        starting_to_compute_node_type_features = time.time()
         holdout_node_type_features = cls.normalize_node_type_features(
             train,
             random_state=random_state*(holdout_number+1),
@@ -1442,12 +1462,15 @@ class AbstractClassifierModel(AbstractModel):
             allow_automatic_feature=True,
             skip_evaluation_biased_feature=False,
             smoke_test=smoke_test,
-            precompute_constant_automatic_stocastic_features=True
+            precompute_constant_stocastic_features=True
         )
+        time_required_to_compute_node_type_features = time.time(
+        ) - starting_to_compute_node_type_features
 
         # We execute the same thing as described above,
         # but now for the edge features instead that for
         # the node features.
+        starting_to_compute_edge_features = time.time()
         holdout_edge_features = cls.normalize_edge_features(
             train,
             random_state=random_state*(holdout_number+1),
@@ -1455,8 +1478,10 @@ class AbstractClassifierModel(AbstractModel):
             allow_automatic_feature=True,
             skip_evaluation_biased_feature=False,
             smoke_test=smoke_test,
-            precompute_constant_automatic_stocastic_features=True
+            precompute_constant_stocastic_features=True
         )
+        time_required_to_compute_edge_features = time.time() - \
+            starting_to_compute_edge_features
 
         if subgraph_of_interest is not None:
             # First we align the train and test graph to have
@@ -1471,22 +1496,6 @@ class AbstractClassifierModel(AbstractModel):
                     node_names_to_keep_from_graph=subgraph_of_interest
                 )
 
-                # We enable in the train and test graphs of interest the same
-                # speedups enabled in the provided graph.
-                train.enable(
-                    vector_sources=graph.has_sources_tradeoff_enabled(),
-                    vector_destinations=graph.has_destinations_tradeoff_enabled(),
-                    vector_cumulative_node_degrees=graph.has_cumulative_node_degrees_tradeoff_enabled(),
-                    vector_reciprocal_sqrt_degrees=graph.has_reciprocal_sqrt_degrees_tradeoff_enabled()
-                )
-
-                test.enable(
-                    vector_sources=graph.has_sources_tradeoff_enabled(),
-                    vector_destinations=graph.has_destinations_tradeoff_enabled(),
-                    vector_cumulative_node_degrees=graph.has_cumulative_node_degrees_tradeoff_enabled(),
-                    vector_reciprocal_sqrt_degrees=graph.has_reciprocal_sqrt_degrees_tradeoff_enabled()
-                )
-
                 # We adjust the node features to only include the node features
                 # that the subgraph of interest allows us to use.
                 if holdout_node_features is not None:
@@ -1525,25 +1534,26 @@ class AbstractClassifierModel(AbstractModel):
                         "subgraph of interest, does not have any more edges which are "
                         f"essential when running a {cls.task_name()} task."
                     )
-            # We enable in the train and test graphs of interest the same
-            # speedups enabled in the provided graph.
-            train_of_interest.enable(
-                vector_sources=graph.has_sources_tradeoff_enabled(),
-                vector_destinations=graph.has_destinations_tradeoff_enabled(),
-                vector_cumulative_node_degrees=graph.has_cumulative_node_degrees_tradeoff_enabled(),
-                vector_reciprocal_sqrt_degrees=graph.has_reciprocal_sqrt_degrees_tradeoff_enabled()
-            )
-
-            test_of_interest.enable(
-                vector_sources=graph.has_sources_tradeoff_enabled(),
-                vector_destinations=graph.has_destinations_tradeoff_enabled(),
-                vector_cumulative_node_degrees=graph.has_cumulative_node_degrees_tradeoff_enabled(),
-                vector_reciprocal_sqrt_degrees=graph.has_reciprocal_sqrt_degrees_tradeoff_enabled()
-            )
         else:
             train_of_interest = train
             test_of_interest = test
 
+        # We enable in the train and test graphs of interest the same
+        # speedups enabled in the provided graph.
+        train_of_interest.enable(
+            vector_sources=graph.has_sources_tradeoff_enabled(),
+            vector_destinations=graph.has_destinations_tradeoff_enabled(),
+            vector_cumulative_node_degrees=graph.has_cumulative_node_degrees_tradeoff_enabled(),
+            vector_reciprocal_sqrt_degrees=graph.has_reciprocal_sqrt_degrees_tradeoff_enabled()
+        )
+
+        test_of_interest.enable(
+            vector_sources=graph.has_sources_tradeoff_enabled(),
+            vector_destinations=graph.has_destinations_tradeoff_enabled(),
+            vector_cumulative_node_degrees=graph.has_cumulative_node_degrees_tradeoff_enabled(),
+            vector_reciprocal_sqrt_degrees=graph.has_reciprocal_sqrt_degrees_tradeoff_enabled()
+        )
+
         additional_validation_kwargs = cls._prepare_evaluation(
             graph=graph,
             support=train,
@@ -1558,7 +1568,7 @@ class AbstractClassifierModel(AbstractModel):
         time_required_for_setting_up_holdout = time.time() - starting_setting_up_holdout
 
         holdout_performance = pd.concat([
-            classifier.__train_and_evaluate_model(
+            classifier._train_and_evaluate_model(
                 graph=graph,
                 train_of_interest=train_of_interest,
                 test_of_interest=test_of_interest,
@@ -1572,8 +1582,8 @@ class AbstractClassifierModel(AbstractModel):
                 holdout_number=holdout_number,
                 evaluation_schema=evaluation_schema,
                 enable_cache=enable_cache,
-                automatic_features_names=automatic_features_names,
-                automatic_features_parameters=automatic_features_parameters,
+                features_names=features_names,
+                features_parameters=features_parameters,
                 **additional_validation_kwargs,
                 **validation_kwargs,
             )
@@ -1585,6 +1595,9 @@ class AbstractClassifierModel(AbstractModel):
         ])
 
         holdout_performance["time_required_for_setting_up_holdout"] = time_required_for_setting_up_holdout
+        holdout_performance["time_required_to_compute_node_features"] = time_required_to_compute_node_features
+        holdout_performance["time_required_to_compute_node_type_features"] = time_required_to_compute_node_type_features
+        holdout_performance["time_required_to_compute_edge_features"] = time_required_to_compute_edge_features
 
         return holdout_performance
 
@@ -1613,7 +1626,7 @@ class AbstractClassifierModel(AbstractModel):
         random_state: int = 42,
         verbose: bool = True,
         enable_cache: bool = False,
-        precompute_constant_automatic_stocastic_features: bool = False,
+        precompute_constant_stocastic_features: bool = False,
         smoke_test: bool = False,
         **validation_kwargs: Dict
     ) -> pd.DataFrame:
@@ -1657,7 +1670,7 @@ class AbstractClassifierModel(AbstractModel):
             Whether to show a loading bar while computing holdouts.
         enable_cache: bool = False
             Whether to enable the cache.
-        precompute_constant_automatic_stocastic_features: bool = False
+        precompute_constant_stocastic_features: bool = False
             Whether to precompute once the constant automatic stocastic
             features before starting the embedding loop. This means that,
             when left set to false, while the features will be computed
@@ -1717,7 +1730,7 @@ class AbstractClassifierModel(AbstractModel):
 
         # Retrieve the set of provided automatic features parameters
         # so we can put them in the report.
-        automatic_features_parameters = {
+        features_parameters = {
             parameter_name: value
             for features in (
                 node_features
@@ -1737,7 +1750,7 @@ class AbstractClassifierModel(AbstractModel):
 
         # Retrieve the set of provided automatic features names
         # so we can put them in the report.
-        automatic_features_names = {
+        features_names = {
             feature.model_name()
             for features in (
                 node_features
@@ -1760,41 +1773,50 @@ class AbstractClassifierModel(AbstractModel):
         # This way we compute only once the features that do not
         # cause biases for this task, while recomputing those
         # that cause biases at each holdout, avoiding said biases.
+        starting_to_compute_constant_node_features = time.time()
         node_features = cls.normalize_node_features(
             graph,
             random_state=random_state,
             node_features=node_features,
             allow_automatic_feature=True,
             skip_evaluation_biased_feature=True,
-            precompute_constant_automatic_stocastic_features=precompute_constant_automatic_stocastic_features,
+            precompute_constant_stocastic_features=precompute_constant_stocastic_features,
             smoke_test=smoke_test
         )
+        time_required_to_compute_constant_node_features = time.time(
+        ) - starting_to_compute_constant_node_features
 
         # We execute the same thing as described above,
         # but now for the node type features instead that for
         # the node features.
+        starting_to_compute_constant_node_type_features = time.time()
         node_type_features = cls.normalize_node_type_features(
             graph,
             random_state=random_state,
             node_type_features=node_type_features,
             allow_automatic_feature=True,
             skip_evaluation_biased_feature=True,
-            precompute_constant_automatic_stocastic_features=precompute_constant_automatic_stocastic_features,
+            precompute_constant_stocastic_features=precompute_constant_stocastic_features,
             smoke_test=smoke_test
         )
+        time_required_to_compute_constant_node_type_features = time.time(
+        ) - starting_to_compute_constant_node_type_features
 
         # We execute the same thing as described above,
         # but now for the edge features instead that for
         # the node features.
+        starting_to_compute_constant_edge_features = time.time()
         edge_features = cls.normalize_edge_features(
             graph,
             random_state=random_state,
             edge_features=edge_features,
             allow_automatic_feature=True,
             skip_evaluation_biased_feature=True,
-            precompute_constant_automatic_stocastic_features=precompute_constant_automatic_stocastic_features,
+            precompute_constant_stocastic_features=precompute_constant_stocastic_features,
             smoke_test=smoke_test
         )
+        time_required_to_compute_constant_edge_features = time.time(
+        ) - starting_to_compute_constant_edge_features
 
         # We start to iterate on the holdouts.
         performance = pd.concat([
@@ -1816,8 +1838,8 @@ class AbstractClassifierModel(AbstractModel):
                 holdouts_kwargs=holdouts_kwargs,
                 subgraph_of_interest_has_compatible_nodes=subgraph_of_interest_has_compatible_nodes,
                 verbose=verbose,
-                automatic_features_names=automatic_features_names,
-                automatic_features_parameters=automatic_features_parameters,
+                features_names=features_names,
+                features_parameters=features_parameters,
                 **validation_kwargs
             )
             for holdout_number in trange(
@@ -1839,6 +1861,9 @@ class AbstractClassifierModel(AbstractModel):
         # as often such information changes how the model
         # is trained.
         performance["number_of_holdouts"] = number_of_holdouts
+        performance["time_required_to_compute_constant_node_features"] = time_required_to_compute_constant_node_features
+        performance["time_required_to_compute_constant_node_type_features"] = time_required_to_compute_constant_node_type_features
+        performance["time_required_to_compute_constant_edge_features"] = time_required_to_compute_constant_edge_features
 
         # We save the constant values for this model
         # execution.
